draw_barplot: This function draws a barplot of sales volume for three years...

Description Usage Arguments Examples

View source: R/draw_barplot.R

Description

This function draws a barplot of sales volume for three years with data

Usage

1

Arguments

data

A tibble object which has "name" & "value" columns

Examples

1
2
3
4
## Not run: 
draw_barplot(sales)

## End(Not run)

MrKevinNa/Sales3Yrs documentation built on Dec. 31, 2020, 3:19 p.m.